==> phpwiki-1.2.2.tbz: www/data-dist/phpwiki/locale/sv/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Du har angett ett otilltet anvndarnamn eller lsenord.";
$locale["You are about to remove '%s' permanently!"] =
   "Du kommer att ta bort \"%s\" permanent!";
$locale["Click %shere%s to remove the page now."] =
   "Klicka %shr%s fr att ta bort sidan nu.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Annars klicka p backaknappen i din webblsare.";
$locale["Function not yet implemented."] =
   "Funktionen r nnu inte implementerad.";
$locale["Remove page"] =
   "Ta bort sida";
$locale["Removed page '%s' succesfully."] =
   "Tog bort sidan \"%s\".";
$locale["templates/browse.html"] =
   "locale/sv/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/sv/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/sv/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/sv/templates/message.html";
$locale["./pgsrc"] =
   "locale/sv/pgsrc";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::apply: radantalet stmmer inte: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: misslyckades";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: ndringssekvensen r icke optimal";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "Nuvarande sida:";
$locale["version %s"] =
   "version %s";
$locale["last modified on %s"] =
   "senast ndrad %s";
$locale["by %s"] =
   "av %s";
$locale["None"] =
   "ingen";
$locale["Archived page:"] =
   "Arkiverad sida:";
$locale["Versions are identical"] =
   "Versionerna r identiska";
$locale["Diff of %s."] =
   "Diff av %s.";
$locale["FrontPage"] =
   "Framsida";
$locale["Describe %s here."] =
   "Beskriv %s hr.";
$locale["Copy of %s"] =
   "Kopia av %s";
$locale["No page name passed into editpage!"] =
   "Ingen sida r angiven!";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Den hr sidan r lst av administratren och kan ej redigeras.";
$locale["Sorry for the inconvenience."] =
   "Ledsen fr allt besvr.";
$locale["Problem while editing %s"] =
   "Har problem med att redigera %s";
$locale["Searching for \"%s\" ....."] =
   "Sker efter \"%s\" .....";
$locale["%d matches found in %d pages."] =
   "%d trffar funna p %d sidor.";
$locale["Full Text Search Results"] =
   "Skresultat fr fulltextskning";
$locale["Cannot establish connection to database, giving up."] =
   "Ger upp, kan ej skapa anslutning till databasen.";
$locale["Error message: %s"] =
   "Felmeddelande: %s";
$locale["Cannot open database %s, giving up."] =
   "Ger upp, kan ej ppna databasen %s.";
$locale["Insert/update failed: %s"] =
   "Insttning/uppdatering misslyckades: %s";
$locale["Delete on %s failed: %s"] =
   "Borttagning p %s misslyckades: %s";
$locale["Insert into %s failed: %s"] =
   "Insttning till %s misslyckades: %s";
$locale["MySQL error: %s"] =
   "MySQL-fel: %s";
$locale["Error writing page '%s'"] =
   "Kunde inte spara sidan \"%s\"";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kan ej ta bort \"%s\" frn tabellen \"%s\"";
$locale["Enter a page name"] =
   "Ange ett sidnamn";
$locale["Go"] =
   "\"G till sidan\"";
$locale["Show the page source and references"] =
   "Visa kllkoden och referenser fr sidan";
$locale["PageInfo"] =
   "Sidinformation fr";
$locale["Page name '%s' is not in the database"] =
   "Sidnamnet \"%s\" finns inte i databasen";
$locale["Current version"] =
   "Nuvarande version";
$locale["Archived version"] =
   "Arkiverad version";
$locale["RecentChanges"] =
   "Senastendringar";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kan inte spara dina ndringar eftersom en annan anvndare ndrade och sparade sidan under tiden som du ndrade p sidan. Sparar du nu frsvinner ndringarna gjorda av den frra anvndaren.";
$locale["In order to recover from this situation follow these steps:"] =
   "Fr att lsa situtationen, flj dessa steg:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Anvnd webblsarens <b>backaknapp</b> fr att g tillbaka till redigeringssidan.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopiera dina ndringar till urklippet eller till ett annat temporrt stlle (t.ex. en texteditor).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Ladda om</b> sidan. Du kommer nu se den senaste versionen av sidan. Dina ndringar r inte dr.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "ndra filen igen. Klistra in dina ndringar frn urklippet (eller texteditorn).";
$locale["Press <b>Save</b> again."] =
   "Klicka p <b>Spara</b> igen.";
$locale["Problem while updating %s"] =
   "Har problem med att uppdatera %s";
$locale["Thank you for editing %s."] =
   "Tack fr att du redigerade %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Din omstnksamhet fr detaljer r mycket uppskattad.";
$locale["%d pages match your query."] =
   "%d sidor matchar din frga.";
$locale["Title Search Results"] =
   "Skresultat fr fulltextskning";
$locale["Inserting page %s, version %s from %s"] =
   "Stter in sidan %s, version %sfrn %s";
$locale["WikiFatalError"] =
   "WikiFatalError";
$locale["Search"] =
   "Sk";
$locale["Nesting depth exceeded in SetHTMLOutputMode"] =
   "Stackgrns verskriden i SetHTMLOutputMode";
$locale["%d best incoming links:"] =
   "De %d mest anvnda ingende lnkarna:";
$locale["%d best outgoing links:"] =
   "De %d mest anvnda utgende lnkarna:";
$locale["%d most popular nearby:"] =
   "De %d mest populra grannarna:";

;?>

==> phpwiki-1.2.10_1.tbz: www/data-dist/phpwiki/locale/sv/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Du har angivit ett felaktigt anvndarnamn eller lsenord.";
$locale["You are about to remove '%s' permanently!"] =
   "Du kommer att ta bort \"%s\" permanent!";
$locale["Click %shere%s to remove the page now."] =
   "Klicka %shr%s fr att ta bort sidan nu.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Klicka annars p backaknappen i din webblsare.";
$locale["Function not yet implemented."] =
   "Funktionen r nnu inte implementerad.";
$locale["Remove page"] =
   "Ta bort sida";
$locale["Removed page '%s' succesfully."] =
   "Tog bort sidan '%s'.";
$locale["Pages which link to %s"] =
   "Sidor som lnkar till %s";
$locale["%d pages link to %s."] =
   "%d sidor lnkar till %s.";
$locale["templates/browse.html"] =
   "locale/sv/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/sv/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/sv/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/sv/templates/message.html";
$locale["./pgsrc"] =
   "locale/sv/pgsrc";
$locale["'%s': corrupt file"] =
   "\"%s\": trasig fil";
$locale["%s: bad data<br>\n"] =
   "%s: felaktig data<br>\n";
$locale["%s: Bad filename in database<br>\n"] =
   "%s: felaktigt filnamn i databasen<br>\n";
$locale["WikiDiff::apply: line count mismatch: %s != %s"] =
   "WikiDiff::apply: radantalet stmmer inte: %s != %s";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: misslyckades";
$locale["WikiDiff::_check: edit sequence is non-optimal"] =
   "WikiDiff::_check: ndringssekvensen r ej optimal";
$locale["WikiDiff Okay: LCS = %s"] =
   "WikiDiff Ok: LCS = %s";
$locale["Current page:"] =
   "Nuvarande sida:";
$locale["version %s"] =
   "version %s";
$locale["last modified on %s"] =
   "senast ndrad %s";
$locale["by %s"] =
   "av %s";
$locale["None"] =
   "ingen";
$locale["Archived page:"] =
   "Arkiverad sida:";
$locale["Versions are identical"] =
   "Versionerna r identiska";
$locale["Diff of %s."] =
   "Diff av %s.";
$locale["FrontPage"] =
   "Framsida";
$locale["Describe %s here."] =
   "Beskriv %s hr.";
$locale["Copy of %s"] =
   "Kopia av %s";
$locale["No page name passed into editpage!"] =
   "Ingen sida r angiven!";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Den hr sidan r lst av administratren och kan ej redigeras.";
$locale["Sorry for the inconvenience."] =
   "Ledsen fr allt besvr.";
$locale["Problem while editing %s"] =
   "Kan ej redigera %s";
$locale["Searching for \"%s\" ....."] =
   "Sker efter \"%s\" .....";
$locale["(You entered an empty search string)"] =
   "(Du har angivit en tom skstrng)";
$locale["%d matches found in %d pages."] =
   "%d trffar funna p %d sidor.";
$locale["Full Text Search Results"] =
   "Skresultat fr fulltextskning";
$locale["Cannot establish connection to database, giving up."] =
   "Ger upp, kan ej skapa anslutning till databasen.";
$locale["Error message: %s"] =
   "Felmeddelande: %s";
$locale["Cannot open database %s, giving up."] =
   "Ger upp, kan ej ppna databasen %s.";
$locale["Insert/update to table 'wiki' failed: %s"] =
   "Insttning/uppdatering i wikitabellen 'wiki' misslyckades: %s";
$locale["Delete on %s failed: %s"] =
   "Borttagning p %s misslyckades: %s";
$locale["Insert into %s failed: %s"] =
   "Insttning till %s misslyckades: %s";
$locale["Insert/update into table 'archive' failed: %s"] =
   "Insttning/uppdatering  i wikitabellen 'archive' misslyckades: %s";
$locale["MSSQL error: %s"] =
   "MSSQL-fel: %s";
$locale["Insert/Update failed: %s"] =
   "Insttning/uppdatering misslyckades: %s";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kan ej ta bort \"%s\" frn tabellen \"%s\"";
$locale["MySQL error: %s"] =
   "MySQL-fel: %s";
$locale["Error writing page '%s'"] =
   "Kunde inte spara sidan \"%s\"";
$locale["Enter a page name"] =
   "Ange ett sidnamn";
$locale["Go"] =
   "\"G till sidan\"";
$locale["Show the page source and references"] =
   "Visa kllkoden och referenser fr sidan";
$locale["PageInfo"] =
   "Sidinformation fr";
$locale["Page name '%s' is not in the database"] =
   "Sidan \"%s\" finns inte i databasen";
$locale["Current version"] =
   "Nuvarande version";
$locale["Archived version"] =
   "Arkiverad version";
$locale["RecentChanges"] =
   "Senastendringar";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kan inte spara dina ndringar eftersom en annan anvndare ndrade och sparade sidan under tiden som du ndrade p sidan. Sparar du nu frsvinner ndringarna gjorda av den frra anvndaren.";
$locale["In order to recover from this situation follow these steps:"] =
   "Fr att lsa situtationen, flj dessa steg:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Anvnd webblsarens <b>backaknapp</b> fr att g tillbaka till redigeringssidan.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopiera dina ndringar till urklippet eller till ett annat temporrt stlle (t.ex. en texteditor).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Ladda om</b> sidan. Du kommer nu se den senaste versionen av sidan. Dina ndringar r inte dr.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "ndra filen igen. Klistra in dina ndringar frn urklippet (eller texteditorn).";
$locale["Press <b>Save</b> again."] =
   "Klicka p <b>Spara</b> igen.";
$locale["Problem while updating %s"] =
   "Kan ej uppdatera %s";
$locale["Thank you for editing %s."] =
   "Tack fr att du redigerade %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Din uppmrksamhet fr detaljer r mycket uppskattad.";
$locale["%d pages match your query."] =
   "%d sidor matchar din frga.";
$locale["Title Search Results"] =
   "Skresultat";
$locale["Inserting page %s, version %s from %s"] =
   "Stter in sidan %s, version %sfrn %s";
$locale["WikiFatalError"] =
   "WikiFatalError";
$locale["Search"] =
   "Sk";
$locale["%d best incoming links:"] =
   "De %d mest anvnda ingende lnkarna:";
$locale["%d best outgoing links:"] =
   "De %d mest anvnda utgende lnkarna:";
$locale["%d most popular nearby:"] =
   "De %d mest populra grannarna:";

;?>
